// SPDX-FileCopyrightText: 2025 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "linyaps_box/status_directory.h"

namespace linyaps_box {
status_directory::~status_directory() = default;
} // namespace linyaps_box
